@@ -16,17 +16,17 @@ import time
 
 import cmd2
 from natural.date import duration
-from texttable import Texttable
-
+from poseidon_cli import __version__
 from poseidon_cli.commands import Commands
 from poseidon_core.constants import NO_DATA
 from poseidon_core.helpers.exception_decor import exception
+from texttable import Texttable
 
 
 readline.parse_and_bind('?: complete')
 
 
-class GetData():
+class GetData:
 
     @staticmethod
     def _get_name(endpoint):
@@ -190,7 +190,7 @@ class GetData():
         return 'No history recorded yet.'
 
 
-class Parser():
+class Parser:
 
     def __init__(self):
         self.default_fields = [
@@ -468,10 +468,8 @@ class PoseidonShell(cmd2.Cmd):
             'role active-directory-controller', 'role administrator-server',
             'role administrator-workstation', 'role business-workstation',
             'role developer-workstation', 'role gpu-laptop', 'role pki-server',
-            'role unknown', 'state active', 'state known',
-            'state unknown', 'state mirroring', 'state shutdown',
-            'state reinvestigating', 'state queued', 'state ignored',
-            'os windows', 'os freebsd',
+            'role unknown', 'state known', 'state unknown', 'state operating',
+            'state queued', 'os windows', 'os freebsd',
             'os linux', 'os mac', 'history', 'version', 'what', 'where', 'all'
         ]
 
@@ -693,9 +691,7 @@ oyyyyy.       oyyyyyyyy`-yyyyyyyyyyyyyysyyyyyyyyyyyyyo /yyyyyyy/
 
     @exception
     def show_version(self, _arg, _flags):
-        with open('/poseidon/VERSION', 'r') as f:  # pragma: no cover
-            for line in f:
-                self.poutput(line.strip())
+        self.poutput(__version__)
 
     @exception
     def task_set(self, arg, flags):
@@ -703,7 +699,6 @@ oyyyyy.       oyyyyyyyy`-yyyyyyyyyyyyyysyyyyyyyyyyyyyo /yyyyyyy/
         Set the state of things on the network:
         SET [IP|MAC|ID] [STATE]
         SET 18:EF:02:2D:49:00 KNOWN
-        SET 8579d412f787432c1a3864c1833e48efb6e61dd466e39038a674f64652129293 SHUTDOWN
         '''
         # defaults
         fields = self.parser.default_fields + ['State', 'Next State']
